@@ -63,6 +63,18 @@ class AppSettings(object):
     def APIGATEWAY_HOST(self):
         return self._setting('APIGATEWAY_HOST', 'http://kong:8001')
 
+    @property
+    def APIGATEWAY_CONSUMER_CUSTOM_ID_HEADER(self):
+        return self._setting('APIGATEWAY_CONSUMER_CUSTOM_ID_HEADER', 'HTTP_X_CONSUMER_CUSTOM_ID')
+
+    @property
+    def APIGATEWAY_CONSUMER_GROUPS_HEADER(self):
+        return self._setting('APIGATEWAY_CONSUMER_GROUPS_HEADER', 'HTTP_X_CONSUMER_GROUPS')
+
+    @property
+    def APIGATEWAY_ANONYMOUS_CONSUMER_HEADER(self):
+        return self._setting('APIGATEWAY_ANONYMOUS_CONSUMER_HEADER', 'HTTP_X_ANONYMOUS_CONSUMER')
+
     @property
     def BACKEND_STANDALONE(self):
         return self.SHAPE.find('standalone') > -1
@@ -96,26 +108,6 @@ class AppSettings(object):
     def COOKIE_HTTPONLY(self):
         return self._django_setting('COOKIE_HTTPONLY', True, bool)
 
-    @property
-    def APIGATEWAY_CONSUMER_GROUP(self):
-        return self._setting('APIGATEWAY_CONSUMER_GROUP', self.COOKIE_DOMAIN)
-
-    @property
-    def APIGATEWAY_CONSUMER_USERNAME_HEADER(self):
-        return self._setting('APIGATEWAY_CONSUMER_USERNAME_HEADER', 'HTTP_X_CONSUMER_USERNAME')
-
-    @property
-    def APIGATEWAY_ANONYMOUS_CONSUMER_USERNAME(self):
-        return self._setting('APIGATEWAY_ANONYMOUS_CONSUMER_USERNAME', 'anonymous')
-
-    @property
-    def APIGATEWAY_ANONYMOUS_CONSUMER_USERNAMES(self):
-        return self._setting('APIGATEWAY_ANONYMOUS_CONSUMER_USERNAMES', [self.APIGATEWAY_ANONYMOUS_CONSUMER_USERNAME])
-
-    @property
-    def APIGATEWAY_CONSUMER_GROUPS_HEADER(self):
-        return self._setting('APIGATEWAY_CONSUMER_GROUPS_HEADER', 'HTTP_X_CONSUMER_GROUPS')
-
     @property
     def BACKEND_SIGNUP_MUST_FILL_PROFILE(self):
         return self._setting('BACKEND_SIGNUP_MUST_FILL_PROFILE', False, bool)
@@ -286,15 +278,15 @@ class AppSettings(object):
 
     @property
     def REMOTE_LOGIN_URL(self):
-        return self.BACKEND_URL + '/login/'
+        return self.BACKEND_URL + '/login/' + '?next=' + self.SERVICE_URL
 
     @property
     def REMOTE_LOGOUT_URL(self):
-        return self.BACKEND_URL + '/logout/'
+        return self.BACKEND_URL + '/logout/' + '?next=' + self.SERVICE_URL
 
     @property
     def REMOTE_SIGNUP_URL(self):
-        return self.BACKEND_URL + '/signin/'
+        return self.BACKEND_URL + '/signup/' + '?next=' + self.SERVICE_URL
 
     @property
     def REMOTE_EMAIL_URL(self):
@@ -340,6 +332,10 @@ class AppSettings(object):
     def DEFAULT_USER_GROUPS(self):
         return self._setting('DEFAULT_USER_GROUPS', [], list)
 
+    @property
+    def DEFAULT_PROFILE_GROUPS(self):
+        return self._setting('DEFAULT_PROFILE_GROUPS', [], list)
+
     @property
     def SAME_SITE_COOKIE_NONE(self):
         return self._setting('SAME_SITE_COOKIE_NONE', False, bool)
