@@ -13,5 +13,5 @@ class Group(DjangoGroup):
         app_label = 'django_sso_app'
         verbose_name = _('Group')
 
-    def get_absolute_rest_url(self):
+    def get_relative_rest_url(self):
         return reverse("django_sso_app_group:rest-detail", args=[self.pk])
