@@ -145,7 +145,7 @@ class Profile(AbstractProfileModel):
         if not creating:
             self.refresh_from_db()
 
-    def get_absolute_rest_url(self):
+    def get_relative_rest_url(self):
         return reverse("django_sso_app_profile:rest-detail", args=[self.sso_id])
 
     def add_to_group(self, group_name, creating=False):
@@ -158,7 +158,27 @@ class Profile(AbstractProfileModel):
         if creating:
             setattr(self.user, '__dssoa__creating', True)
 
-        self.groups.add(g)
+        if g not in self.groups.all():
+            self.groups.add(g)
+
+        if creating:
+            setattr(self.user, '__dssoa__creating', False)
+
+    def remove_from_group(self, group_name, creating=False):
+        logger.info('Removing "{}" from group "{}"'.format(self, group_name))
+
+        g, _created = Group.objects.get_or_create(name=group_name)
+        if _created:
+            logger.info('New group "{}" created'.format(g))
+
+        if creating:
+            setattr(self.user, '__dssoa__creating', True)
+
+        if g in self.groups.all():
+            self.groups.remove(g)
+
+        if creating:
+            setattr(self.user, '__dssoa__creating', False)
 
     @property
     def username(self):
@@ -176,21 +196,19 @@ class Profile(AbstractProfileModel):
 
     @property
     def is_incomplete(self):
-        is_incomplete = False
-
         for field in app_settings.REQUIRED_PROFILE_FIELDS:
             if getattr(self, field, None) in [None, '']:
-                is_incomplete = True
+                logger.debug('Empty "{}" field'.format(field))
+                return True
 
-        return is_incomplete
+        return False
 
     @property
     def must_subscribe(self):
         if app_settings.SERVICE_SUBSCRIPTION_REQUIRED:
-            user_service_subscription = self.subscriptions.filter(service__service_url=app_settings.SERVICE_URL,
-                                                                  is_unsubscribed=False).first()
+            user_service_subscription = self.subscriptions.filter(service__service_url=app_settings.SERVICE_URL).first()
 
-            if user_service_subscription is None:
+            if user_service_subscription is None or user_service_subscription.is_unsubscribed:
                 return True
 
         return self.is_unsubscribed
