@@ -106,7 +106,7 @@ class ProfileSerializer(AbsoluteUrlSerializer):
         try:
             user = instance.user
             request = self.context['request']
-            return request.build_absolute_uri(user.get_absolute_rest_url())
+            return request.build_absolute_uri(user.get_relative_rest_url())
         except:
             logger.warning('No profile.user url for {}.'.format(instance))
 
