@@ -2,29 +2,23 @@ import logging
 
 from django.contrib.auth import get_user_model
 from django.shortcuts import redirect
-from django.urls import reverse
-from django.urls import reverse_lazy
+from django.urls import reverse, reverse_lazy
 from django.views.generic import UpdateView
 from django.contrib.auth.mixins import LoginRequiredMixin
 
 from rest_framework import permissions
-from rest_framework import status
 from rest_framework import viewsets
-from rest_framework.response import Response
 from rest_framework import generics
 
 from django_filters.rest_framework import DjangoFilterBackend
 
-from allauth.account.adapter import get_adapter
-
 from .forms import UserProfileForm
 from .models import Profile
-from .serializers import ProfileSerializer, ProfilePublicSerializer, ProfileUnsubscriptionSerializer
+from .serializers import ProfileSerializer
 from ... import app_settings
-
 from ...permissions import is_staff
-from ...utils import invalidate_cookie
 from ...mixins import WebpackBuiltTemplateViewMixin
+from ...views import DjangoSsoAppBaseViewMixin
 
 from .filters import ProfileFilter
 
@@ -43,11 +37,9 @@ class ProfileView(LoginRequiredMixin, WebpackBuiltTemplateViewMixin):
 
     def get_context_data(self, *args, **kwargs):
         context = super(ProfileView, self).get_context_data(*args, **kwargs)
-        self.object = self.get_object()
-
-        if self.object is not None:
-            profile = self.object
+        profile = self.get_object()
 
+        if profile is not None:
             user_fields = []
             for field in app_settings.PROFILE_FIELDS:
                 user_fields.append((field, getattr(profile, field)))
@@ -109,9 +101,7 @@ class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateView
 
         else:
             user = profile.user
-            adapter = get_adapter(request)
-
-            adapter.try_update_response_jwt(user, response)
+            self.update_response_jwt(user, response)
 
             return response
 
@@ -138,7 +128,8 @@ class ProfileCompleteView(ProfileUpdateView):
 
 # api
 
-class ProfileApiViewSet(viewsets.ModelViewSet):
+class ProfileApiViewSet(viewsets.ModelViewSet,
+                        DjangoSsoAppBaseViewMixin):
     lookup_field = 'sso_id'
     permission_classes = (permissions.IsAuthenticated, )
     filter_backends = (DjangoFilterBackend,)
@@ -177,52 +168,7 @@ class ProfileApiViewSet(viewsets.ModelViewSet):
             profile = self.get_object()
             user = profile.user
 
-            adapter = get_adapter(request)
-            adapter.try_update_response_jwt(user, response)
-
-        return response
-
-
-class ProfileCompleteUnsubscriptionApiView(viewsets.GenericViewSet):
-    """
-    Completely unsubscribe user
-    """
-
-    permission_classes = (permissions.IsAuthenticated, )
-    serializer_class = ProfileUnsubscriptionSerializer
-
-    def get_serializer(self, *args, **kwargs):
-        request = self.request
-        serializer_class = self.get_serializer_class()
-
-        return serializer_class(data=request.data, context={'request': request})
-
-    def completely_unsubscribe(self, request, sso_id, *args, **kwargs):
-        logger.info('ProfileCompleteUnsubscriptionApiView {}'.format(sso_id))
-
-        requesting_user = request.user
-        serializer = self.get_serializer()
-
-        if not serializer.is_valid():
-            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-
-        adapter = get_adapter(request)
-
-        username = requesting_user.username
-        email = requesting_user.email
-        password = serializer.data.get('password')
-
-        try:
-            adapter.try_completely_unsubscribe(username, email, password)
-
-        except:
-            logger.exception('completely_unsubscribe error')
-            response = Response('Error unsubscribing completely', status=status.HTTP_500_INTERNAL_SERVER_ERROR)
-
-        else:
-            response = Response('Successfully completely unsubscribed.', status=status.HTTP_200_OK)
-
-        invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
+            self.update_response_jwt(user, response)
 
         return response
 
