@@ -11,6 +11,7 @@ from .apps.emails.models import EmailAddress
 from .apps.services.models import Service
 from .apps.groups.models import Group
 
+from .utils import set_session_key
 from . import app_settings
 
 logger = logging.getLogger('django_sso_app.core')
@@ -73,7 +74,6 @@ class BaseSignupForm(allauth_SignupForm):
     def save(self, request):
         new_user = super(BaseSignupForm, self).save(request)
 
-        adapter = get_adapter(request)
         referer = self.cleaned_data["referer"]
         groups = self.cleaned_data.get("groups", '')
 
@@ -85,7 +85,7 @@ class BaseSignupForm(allauth_SignupForm):
 
                     service = Service.objects.filter(service_url=referer).first()
                     if service is not None:
-                        adapter.subscribe_profile_to_service(new_user.sso_app_profile, service)
+                        _subscription, _created = service.subscribe(new_user.get_sso_app_profile())
 
                 # subscribing user to groups
                 if len(groups):
