@@ -2,6 +2,7 @@ import logging
 import os
 
 # from django.conf import settings
+from django.core.exceptions import SuspiciousOperation
 from django.shortcuts import redirect
 from django.urls import reverse
 from django.http import HttpResponse
@@ -14,7 +15,9 @@ from allauth.account import views as allauth_account_views
 from allauth.account.adapter import get_adapter
 from allauth.socialaccount import views as allauth_socialaccount_views
 
-from .permissions import is_django_staff, is_authenticated
+from .apps.devices.utils import renew_response_jwt
+from .permissions import is_django_staff, is_authenticated, is_staff
+from .tokens.utils import get_request_jwt
 from .utils import set_cookie, invalidate_cookie, set_session_key, get_session_key, get_random_fingerprint
 from .mixins import WebpackBuiltTemplateViewMixin
 from . import app_settings
@@ -24,14 +27,48 @@ logger = logging.getLogger('django_sso_app.core')
 CURRENT_DIR = os.getcwd()
 
 
-class DjangoSsoAppBaseViewMixin():
+class DjangoSsoAppBaseViewMixin:
+    def update_response_jwt(self, user, response):
+        """
+        Updated response JWT (if in request)
+        """
+        if self.request is None:
+            raise KeyError('no request object')
+
+        requesting_user = self.request.user
+
+        if not is_django_staff(requesting_user):
+            logger.info('Updating response jwt for "{}"'.format(user))
+            received_jwt = get_request_jwt(self.request)
+
+            if received_jwt is not None:
+                is_same_user = requesting_user == user
+
+                if is_same_user:
+                    logger.info('From browser as same user "{}"'.format(user))
+                    renew_response_jwt(received_jwt, user, self.request, response)
+
+                elif not is_same_user and is_staff(requesting_user):
+                    # returns user jwt to staff user  #Q!
+                    logger.info('From browser as staff user "{}"'.format(requesting_user))
+                    renew_response_jwt(received_jwt, user, self.request, response)
+
+                else:
+                    _msg = 'User "{}" can not update response JWT for "{}"'.format(requesting_user, user)
+                    logger.warning(_msg)
+
+                    raise SuspiciousOperation(_msg)
+
+
+class DjangoSsoAppViewMixin(DjangoSsoAppBaseViewMixin):
     def __init__(self, *args, **kwargs):
-        super(DjangoSsoAppBaseViewMixin, self).__init__(*args, **kwargs)
+        super(DjangoSsoAppViewMixin, self).__init__(*args, **kwargs)
 
         if not hasattr(self, 'object'):
             setattr(self, 'object', None)
 
-    def get_request_fingerprint(self, request):
+    @staticmethod
+    def get_request_fingerprint(request):
         return request.POST.get('fingerprint', get_random_fingerprint(request))
 
     @staticmethod
@@ -52,14 +89,11 @@ class DjangoSsoAppBaseViewMixin():
 
 # allauth views
 
-class LoginView(allauth_account_views.LoginView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
+class LoginView(allauth_account_views.LoginView, DjangoSsoAppViewMixin, WebpackBuiltTemplateViewMixin):
 
     def get(self, request, *args, **kwargs):
         logger.info('Getting login')
 
-        #if is_authenticated(request.user):
-        #    return redirect(reverse('profile'))
-
         try:
             return super(LoginView, self).get(request, *args, **kwargs)
 
@@ -70,16 +104,12 @@ class LoginView(allauth_account_views.LoginView, DjangoSsoAppBaseViewMixin, Webp
     def post(self, request, *args, **kwargs):
         logger.info('Logging in')
 
-        if is_authenticated(request.user):
-            return redirect(reverse('profile'))
-
         try:
             set_session_key(request, '__dssoa__device__fingerprint', self.get_request_fingerprint(request))
-
             response = super(LoginView, self).post(request, *args, **kwargs)
-
             location = response.get('location', None)
             if location == reverse('account_email_verification_sent'):
+                # disable login on signup
                 logger.info('User "must confirm email"'.format(request.user))
 
                 adapter = get_adapter(self.request)
@@ -97,7 +127,7 @@ class LoginView(allauth_account_views.LoginView, DjangoSsoAppBaseViewMixin, Webp
             return response
 
 
-class LogoutView(allauth_account_views.LogoutView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
+class LogoutView(allauth_account_views.LogoutView, DjangoSsoAppViewMixin, WebpackBuiltTemplateViewMixin):
     def get(self, request, *args, **kwargs):
         logger.info('Getting logout')
 
@@ -128,7 +158,7 @@ class LogoutView(allauth_account_views.LogoutView, DjangoSsoAppBaseViewMixin, We
             return self.get_response_with_invalidated_cookie(response)
 
 
-class SignupView(allauth_account_views.SignupView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
+class SignupView(allauth_account_views.SignupView, DjangoSsoAppViewMixin, WebpackBuiltTemplateViewMixin):
     def get(self, request,  *args, **kwargs):
         logger.info('Getting signup')
 
@@ -169,7 +199,7 @@ class SignupView(allauth_account_views.SignupView, DjangoSsoAppBaseViewMixin, We
         return response
 
 
-class ConfirmEmailView(allauth_account_views.ConfirmEmailView, DjangoSsoAppBaseViewMixin):
+class ConfirmEmailView(allauth_account_views.ConfirmEmailView, DjangoSsoAppViewMixin):
     def get(self, request, *args, **kwargs):
         logger.info('Getting confirm email')
 
@@ -249,7 +279,7 @@ class PasswordChangeView(allauth_account_views.PasswordChangeView):
             raise
 
 
-class PasswordSetView(allauth_account_views.PasswordSetView, DjangoSsoAppBaseViewMixin):
+class PasswordSetView(allauth_account_views.PasswordSetView, DjangoSsoAppViewMixin):
     def get(self, *args, **kwargs):
         logger.info('Getting password set')
 
@@ -271,13 +301,12 @@ class PasswordSetView(allauth_account_views.PasswordSetView, DjangoSsoAppBaseVie
             raise
 
         else:
-            adapter = get_adapter(request)
-            adapter.try_update_response_jwt(request.user, response)
+            self.update_response_jwt(request.user, response)
 
             return response
 
 
-class PasswordResetView(allauth_account_views.PasswordResetView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
+class PasswordResetView(allauth_account_views.PasswordResetView, DjangoSsoAppViewMixin, WebpackBuiltTemplateViewMixin):
     def get(self, *args, **kwargs):
         logger.info('Getting ask password reset')
 
@@ -311,7 +340,7 @@ class PasswordResetDoneView(allauth_account_views.PasswordResetDoneView):
             raise
 
 
-class PasswordResetFromKeyView(allauth_account_views.PasswordResetFromKeyView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
+class PasswordResetFromKeyView(allauth_account_views.PasswordResetFromKeyView, DjangoSsoAppViewMixin, WebpackBuiltTemplateViewMixin):
 
     def dispatch(self, request, uidb36, key, **kwargs):
         _response = super(PasswordResetFromKeyView, self).dispatch(request, uidb36, key, **kwargs)
@@ -371,7 +400,7 @@ class AccountInactiveView(allauth_account_views.AccountInactiveView):
             raise
 
 
-class EmailVerificationSentView(allauth_account_views.EmailVerificationSentView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
+class EmailVerificationSentView(allauth_account_views.EmailVerificationSentView, DjangoSsoAppViewMixin, WebpackBuiltTemplateViewMixin):
     def get(self, *args, **kwargs):
         logger.info('Getting email verification sent')
 
